@@ -3,9 +3,9 @@ use core::cmp::{Ordering, PartialOrd};
 use core::intrinsics;
 
 #[inline(always)]
-pub(crate) fn distance_between<T>(dest: *const T, origin: *const T) -> usize {
+pub(crate) const fn distance_between<T>(dest: *const T, origin: *const T) -> usize {
   match intrinsics::size_of::<T>() {
-    0 => (dest as usize).wrapping_sub(origin as usize),
+    0 => unsafe { (dest as usize).wrapping_sub(origin as usize) },
     _ => unsafe {
       intrinsics::exact_div(
         (dest as usize).wrapping_sub(origin as usize),
@@ -28,12 +28,12 @@ where T: Copy {
 }
 
 #[inline(always)]
-pub fn new_from_value<T, const COUNT: usize>(value: T) -> StaticVec<T, { COUNT }>
+pub fn new_from_value<T, const COUNT: usize>(value: T) -> StaticVec<T, COUNT>
 where T: Copy {
-  StaticVec::<T, { COUNT }> {
+  StaticVec {
     data: {
       unsafe {
-        let mut data = StaticVec::<T, { COUNT }>::new_data_uninit();
+        let mut data = StaticVec::new_data_uninit();
         for i in 0..COUNT {
           (data.as_mut_ptr() as *mut T).add(i).write(value);
         }
