@@ -1,6 +1,5 @@
 #![allow(clippy::all)]
 #![allow(dead_code)]
-#![feature(type_name_of_val)]
 
 use staticvec::*;
 
@@ -9,6 +8,9 @@ use core::cell;
 #[cfg(feature = "std")]
 use std::panic::{self, AssertUnwindSafe};
 
+#[cfg(feature = "std")]
+use std::io::{IoSlice, Write};
+
 #[cfg(not(miri))]
 #[cfg(feature = "std")]
 use cool_asserts::assert_panics;
@@ -91,9 +93,6 @@ impl Drop for Struct {
   }
 }
 
-#[cfg(feature = "std")]
-use std::io::{IoSlice, Write};
-
 #[test]
 fn append() {
   let mut a = staticvec![Struct { s: "A" }, Struct { s: "B" }, Struct { s: "C" }];
@@ -213,7 +212,6 @@ fn clone_from_longer() {
 fn panicking_clone() {
   // An earlier implementation of clone incorrectly leaked values in the event
   // of a panicking clone. This test ensures that that does not happen.
-
   // This struct will, if so configured, panic on a clone. Uses
   // LifespanCountingInstance to track instantiations and deletions, so that
   // we can ensure the correct number of drops are happening
@@ -477,6 +475,12 @@ fn iter() {
   let mut i = v.iter();
   assert_eq!(*i.next().unwrap(), 1);
   assert_eq!(*i.next_back().unwrap(), 5);
+  assert_eq!("[2, 3, 4]", format!("{:?}", i));
+  assert_eq!(*i.next().unwrap(), 2);
+  assert_eq!(*i.next_back().unwrap(), 4);
+  assert_eq!("[3]", format!("{:?}", i));
+  assert_eq!(*i.next().unwrap(), 3);
+  assert_eq!("[]", format!("{:?}", i));
 }
 
 #[test]
@@ -485,6 +489,12 @@ fn iter_mut() {
   let mut i = v.iter_mut();
   assert_eq!(*i.next().unwrap(), 1);
   assert_eq!(*i.next_back().unwrap(), 5);
+  assert_eq!("[2, 3, 4]", format!("{:?}", i));
+  assert_eq!(*i.next().unwrap(), 2);
+  assert_eq!(*i.next_back().unwrap(), 4);
+  assert_eq!("[3]", format!("{:?}", i));
+  assert_eq!(*i.next().unwrap(), 3);
+  assert_eq!("[]", format!("{:?}", i));
 }
 
 #[test]
@@ -493,6 +503,12 @@ fn into_iter() {
   let mut i = v.into_iter();
   assert_eq!(i.next().unwrap(), 1);
   assert_eq!(i.next_back().unwrap(), 5);
+  assert_eq!("[2, 3, 4]", format!("{:?}", i));
+  assert_eq!(i.next().unwrap(), 2);
+  assert_eq!(i.next_back().unwrap(), 4);
+  assert_eq!("[3]", format!("{:?}", i));
+  assert_eq!(i.next().unwrap(), 3);
+  assert_eq!("[]", format!("{:?}", i));
 }
 
 #[cfg(feature = "std")]
@@ -535,12 +551,28 @@ fn len() {
 
 #[test]
 fn macros() {
-  // The type of the StaticVec on the next line is `StaticVec<Vec<StaticVec<i32, 4>>, 1>`.
+  // The type of the StaticVec on the next line is `StaticVec<StaticVec<StaticVec<i32, 4>, 1>, 1>`.
   let _v = staticvec![staticvec![staticvec![1, 2, 3, 4]]];
   // The type of the StaticVec on the next line is `StaticVec<f32, 64>`.
   let _v2 = staticvec![12.0; 64];
 }
 
+#[test]
+fn mut_ptr_at() {
+  let mut v = staticvec![1, 2, 3];
+  unsafe { assert_eq!(*v.mut_ptr_at(0), 1) };
+  unsafe { assert_eq!(*v.mut_ptr_at(1), 2) };
+  unsafe { assert_eq!(*v.mut_ptr_at(2), 3) };
+}
+
+#[test]
+fn mut_ptr_at_unchecked() {
+  let mut v = staticvec![1, 2, 3];
+  unsafe { assert_eq!(*v.mut_ptr_at_unchecked(0), 1) };
+  unsafe { assert_eq!(*v.mut_ptr_at_unchecked(1), 2) };
+  unsafe { assert_eq!(*v.mut_ptr_at_unchecked(2), 3) };
+}
+
 #[test]
 fn new() {
   let v = StaticVec::<i32, 1>::new();
@@ -627,6 +659,22 @@ fn pop() {
   assert_eq!(vec, [1, 2]);
 }
 
+#[test]
+fn ptr_at() {
+  let v = staticvec![1, 2, 3];
+  unsafe { assert_eq!(*v.ptr_at(0), 1) };
+  unsafe { assert_eq!(*v.ptr_at(1), 2) };
+  unsafe { assert_eq!(*v.ptr_at(2), 3) };
+}
+
+#[test]
+fn ptr_at_unchecked() {
+  let v = staticvec![1, 2, 3];
+  unsafe { assert_eq!(*v.ptr_at_unchecked(0), 1) };
+  unsafe { assert_eq!(*v.ptr_at_unchecked(1), 2) };
+  unsafe { assert_eq!(*v.ptr_at_unchecked(2), 3) };
+}
+
 #[test]
 fn push() {
   let mut vec = StaticVec::<i32, 4>::new_from_slice(&[1, 2, 3]);
